import { ITopic } from '@aws-cdk/aws-sns';
import { Construct } from '@aws-cdk/core';
/**
 * @stability stable
 */
export interface TopicOptions {
    /**
     * The name of the topic.
     *
     * If you don't specify a name, AWS CloudFormation generates a unique physical ID and uses that ID for the topic name (recommended).
     *
     * @default Generated name
     * @stability stable
     */
    readonly topicName?: string;
    /**
     * The display name of the topic.
     *
     * A developer-defined string that can be used to identify this SNS topic.
     *
     * @default - Not configured
     * @stability stable
     */
    readonly displayName?: string;
    /**
     * Use an existing SNS topic ARN e.g. ('arn:aws:sns:us-east-2:444455556666:MyTopic').
     *
     * @default - Not configured
     * @stability stable
     */
    readonly existingTopicArn?: string;
}
/**
 * @stability stable
 */
export interface SubscribeOptions {
    /**
     * The email address that will be used to subcribe to the SNS topic for billing alert notifications e.g. ['hello@example.org'] or [''hello@example.org', 'admin@example.org'].
     *
     * @stability stable
     */
    readonly emailAddress: string[];
    /**
     * Indicates if the full notification JSON should be sent to the email address or just the message text.
     *
     * @default false (Message text)
     * @stability stable
     */
    readonly json?: boolean;
}
/**
 * @stability stable
 */
export interface BillingTopicProps extends TopicOptions, SubscribeOptions {
}
/**
 * A construct to create a new SNS topic or use an existing SNS topic Arn.
 *
 * It then subscribes the configured email address to the SNS topic or the existing SNS topic Arn.
 *
 * @stability stable
 * @example
 *
 * .org']
 * });
 */
export declare class BillingTopic extends Construct {
    /**
     * @stability stable
     */
    readonly topic: ITopic;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: BillingTopicProps);
    /**
     * Create a SNS topic or use and existing SNS topic arn.
     *
     * @param options
     * @returns
     */
    private createTopicOrUseExisting;
    /**
     * Create email address subscription and associate the SNS topic.
     *
     * @param topic
     * @param options
     */
    private createTopicEmailSubscription;
}
